package ru.ulstu.fc.rule.service;

import org.springframework.stereotype.Service;

import ru.ulstu.fc.rule.repository.FuzzyRuleRepository;
import ru.ulstu.fc.project.service.ProjectService;
import ru.ulstu.fc.rule.model.FuzzyRule;
import ru.ulstu.fc.rule.model.FuzzyRuleForm;

@Service
public class FuzzyRuleService {
    private final FuzzyRuleRepository ruleRepository;
    private final ProjectService projectService;

    public FuzzyRuleService(FuzzyRuleRepository ruleRepository, ProjectService projectService) {
        this.ruleRepository = ruleRepository;
        this.projectService = projectService;
    }

    public FuzzyRule getById(Integer id) {
        return ruleRepository
                .findById(id)
                .orElseThrow(() -> new RuntimeException("Rule not found by id"));
    }

    public Object save(FuzzyRuleForm ruleForm) {
        FuzzyRule rule;
        if (ruleForm.getId() == null || ruleForm.getId() == 0) {
            rule = new FuzzyRule();
        } else {
            rule = getById(ruleForm.getId());
        }
        rule.setProject(projectService.getById(ruleForm.getProjectId()));
        rule.setContent(ruleForm.getContent());
        return ruleRepository.save(rule);
    }

    public void delete(FuzzyRuleForm ruleForm) {
        getById(ruleForm.getId());
        ruleRepository.deleteById(ruleForm.getId());
    }
}
